from setuptools import setup, find_packages

setup(
    name='colordev',
    version='0.2.0',
    author='Oleg Bazaka',
    author_email='bazaka.developer@gmail.com',
    description='''Terminal Text package,
    which allows you to output text with different stylized colors in the terminal''',
    packages=find_packages(),
)
